package com.yoai.react.social;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;

import com.facebook.react.bridge.Callback;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.bridge.WritableNativeMap;
import com.sina.weibo.sdk.auth.AuthInfo;
import com.sina.weibo.sdk.auth.WeiboAuthListener;
import com.sina.weibo.sdk.auth.sso.SsoHandler;
import com.sina.weibo.sdk.exception.WeiboException;

public class WeiboPlugin {

  private static final String TAG = "WeiboPlugin";

  private final Activity activity;

  private SsoHandler ssoHandler;

  public WeiboPlugin(Activity activity) {
    this.activity = activity;
  }

  public void onActivityResult(int requestCode, int resultCode, Intent data) {
    if (ssoHandler != null) {
      ssoHandler.authorizeCallBack(requestCode, resultCode, data);
    }
  }

  private void performAuthorize(final ReadableMap config, final Callback callback) {
    if (config != null) {
      String appKey = config.getString("appKey");
      String redirectUrl = config.getString("redirectUrl");
      String scope = config.getString("scope");

      ssoHandler = new SsoHandler(this.activity, new AuthInfo(this.activity, appKey, redirectUrl, scope));
      ssoHandler.authorize(new WeiboAuthListener() {
        @Override
        public void onComplete(Bundle bundle) {
          Log.d(TAG, "onComplete...bundle=" + bundle);
          WritableNativeMap data = new WritableNativeMap();
          if (bundle != null) {
            data.putString("uid", bundle.getString("uid", null));
            data.putString("accessToken", bundle.getString("access_token", null));
            data.putString("refreshToken", bundle.getString("refresh_token", null));
            data.putString("expiresInSeconds", bundle.getString("expires_in", null));
          }

          if (callback != null) {
            WritableNativeMap result = new WritableNativeMap();
            result.putMap("data", data);
            callback.invoke(result);
          }
        }

        @Override
        public void onWeiboException(WeiboException e) {
          Log.e(TAG, "onWeiboException..." + e.getMessage());
          if (callback != null) {
            WritableNativeMap result = new WritableNativeMap();
            result.putString("error", e.getMessage());
            callback.invoke(result);
          }
        }

        @Override
        public void onCancel() {
          Log.i(TAG, "onCancel...");
          if (callback != null) {
            WritableNativeMap result = new WritableNativeMap();
            result.putBoolean("canceled", true);
            callback.invoke(result);
          }
        }
      });
    }
  }

  public void authorize(final ReadableMap config, final Callback callback) {
    if (this.activity != null) {
      this.activity.runOnUiThread(new Runnable() {
        @Override
        public void run() {
          performAuthorize(config, callback);
        }
      });
    } else {
      Log.e(TAG, "authorize...no activity available");
    }
  }
}
